shouldRebuild property
Optional callback to determine if the widget should rebuild.
Implementation
final bool Function(T previous, T current)? shouldRebuild;
Optional callback to determine if the widget should rebuild.
final bool Function(T previous, T current)? shouldRebuild;