core/events library

Classes

Callbacks
Manages callback functions that can be invoked by events.
MastroEvent<T>
Base class for implementing events in the Mastro framework.

Enums

EventRunningMode
Defines how events should be executed in relation to each other.