MastroEvent<T> class abstract

Base class for implementing events in the Mastro framework.

Constructors

MastroEvent()
Creates a new event instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mode EventRunningMode
Defines how this event should be executed relative to other events.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

implement(T box, Callbacks callback) Future<void>
Implements the event logic.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited